@@ -10,7 +10,7 @@
 #' remember the original values and the statistics will be faulty! 
 #' 
 #' @param model A regression model fit, i.e. the returned object from your 
-#'  regression function, or the output from \code{\link{getCrudeAndAdjustedModelData}}
+#'  regression function, or the output from \code{\link{getCrudeAndAdjustedModelData}()}
 #' @param order A vector with regular expressions for each group, use if youe
 #'  want to reorder the groups in another way than what you've used in your original
 #'  function. You can also use this in order to skip certain variables from the output.
@@ -19,7 +19,7 @@
 #'  abbreviated above or below this value, for instance a value of 1000 
 #'  would give a value of \code{> -1000} for a value of 1001. This gives
 #'  a prettier table when you have very wide confidence intervals. 
-#' @param sprintf_ci_str A string according to \code{\link{sprintf}} to 
+#' @param sprintf_ci_str A string according to \code{\link{sprintf}()} to 
 #'  write the confidence interval where the first \%s is the lower and 
 #'  the second the upper. You can choose to set this through setting the option 
 #'  \code{sprintf_ci_str}, e.g. \code{options(sprintf_ci_str = "\%s - \%s")}.
@@ -58,8 +58,8 @@
 #'  the imputation, the the "raw" model is subtracted from the imputed results.
 #'  The "raw" model is the unimputed model, \code{coef(imputed_model) - coef(raw_model)}.
 #'  The \code{variance.inflation} adds the \code{variance.inflation.impute} from the 
-#'  \code{\link[Hmisc]{fit.mult.impute}} to a separate column. See the description
-#'  for the \code{variance.inflation.impute} in in the \code{\link[Hmisc]{fit.mult.impute}}
+#'  \code{\link[Hmisc]{fit.mult.impute}()} to a separate column. See the description
+#'  for the \code{variance.inflation.impute} in in the \code{\link[Hmisc]{fit.mult.impute}()}
 #'  description.
 #'  Both arguments can be customized by providing a \code{list}. The list can have
 #'  the elements \code{type}, \code{name}, \code{out_str}, and/or \code{digits}.
@@ -68,18 +68,18 @@
 #'  originally intended to be interpreted as \%. The default for \code{coef_change} is to 
 #'  have "diff", that gives the absolute difference in the coefficient.
 #'  The \code{name} provides the column name, the \code{out_str} should be a string
-#'  that is compatible with \code{\link[base]{sprintf}} and also contains an argument
+#'  that is compatible with \code{\link[base]{sprintf}()} and also contains an argument
 #'  for accepting a float value, e.g. "%.0f%%" is used by default iun the coef_change
 #'  column. The \code{digits} can be used if you are not using the \code{out_str}
 #'  argument, it simply specifies the number of digits to show. See the example
 #'  for how for a working example.
-#'  \emph{Note} that currently only the \code{\link[Hmisc]{fit.mult.impute}}
+#'  \emph{Note} that currently only the \code{\link[Hmisc]{fit.mult.impute}()}
 #'  is supported by this option.
-#' @param ... Passed onto the Hmisc::\code{\link{latex}} function, or to 
-#'  the \code{\link{htmlTable}} via the print call. Any variables that match
-#'  the formals of \code{\link{getCrudeAndAdjustedModelData}} are identified
+#' @param ... Passed onto the Hmisc::\code{\link[Hmisc]{latex}()} function, or to 
+#'  the \code{\link[htmlTable]{htmlTable}()} via the \code{\link[base]{print}()} call. Any variables that match
+#'  the formals of \code{\link{getCrudeAndAdjustedModelData}()} are identified
 #'  and passed on in case you have provided a model and not the returned element
-#'  from the \code{\link{getCrudeAndAdjustedModelData}} call.
+#'  from the \code{\link{getCrudeAndAdjustedModelData}()} call.
 #'  
 #' @return \code{matrix} Returns a matrix of class printCrudeAndAdjusted that 
 #'  has a default print method associated with
@@ -391,7 +391,7 @@ rbind.printCrudeAndAdjusted <-
 
 #' @param x The output object from the printCrudeAndAdjustedModel function 
 #' @param css.rgroup Css style for the rgorup, if different styles are wanted for each of the
-#'  rgroups you can just specify a vector with the number of elements. Passed on to \code{\link{htmlTable}}.
+#'  rgroups you can just specify a vector with the number of elements. Passed on to \code{\link{htmlTable}()}.
 #' @rdname printCrudeAndAdjustedModel
 #' @export
 #' @import magrittr
@@ -455,6 +455,15 @@ cbind.printCrudeAndAdjusted <- function(..., alt.names, deparse.level = 1){
   # cbind is an internal generics and thus doesn't
   # work with the NextMethod()
   pca <- list(...)
+  tmp <- list()
+  for (i in 1:length(pca)){
+    if (!is.null(pca[[i]]))
+      tmp[[length(tmp) + 1]] <- pca[[i]]
+  }
+  pca <- tmp
+  if(length(pca) == 1)
+    return(pca[[1]])
+  
   pca_args <- c(prClearPCAclass(pca),
                 list(deparse.level = deparse.level))
   # Check that names are the same in all models
@@ -490,8 +499,9 @@ cbind.printCrudeAndAdjusted <- function(..., alt.names, deparse.level = 1){
 prClearPCAclass <- function(pca){
   all_non_pca <- all(sapply(pca, function(elmnt) inherits(elmnt, "printCrudeAndAdjusted")))
   for (i in 1:length(pca)){
-    class(pca[[i]]) <- 
-      class(pca[[i]])[class(pca[[i]]) != "printCrudeAndAdjusted"]
+    if (!is.null(pca[[i]]))
+      class(pca[[i]]) <- 
+        class(pca[[i]])[class(pca[[i]]) != "printCrudeAndAdjusted"]
   }
   return(pca)
 }
@@ -512,8 +522,8 @@ knit_print.printCrudeAndAdjusted <- function(x,
 
 #' Prep for printing
 #' 
-#' Since we have both the \code{\link[base]{print}} and the
-#' \code{\link[knitr]{knit_print}} that we need to call it is
+#' Since we have both the \code{\link[base]{print}()} and the
+#' \code{\link[knitr]{knit_print}()} that we need to call it is
 #' useful to have a common string preparer.
 #' \emph{Note:} Currently knit_print doesn't work as expected...
 #' 
@@ -562,7 +572,7 @@ prPrintCAstring <- function (x, css.rgroup, ...) {
 }
 
 #' @param object The output object from the printCrudeAndAdjustedModel function 
-#' @seealso \code{\link[Hmisc]{latex}} for details regarding the \code{latex()} function.
+#' @seealso \code{\link[Hmisc]{latex}()} for details.
 #' @rdname printCrudeAndAdjustedModel
 #' @method latex printCrudeAndAdjusted
 #' @export
@@ -598,19 +608,19 @@ latex.printCrudeAndAdjusted <- function(object, ...){
 #' A function for gathering all the description options
 #' 
 #' Since there are so many different description options
-#' for the \code{\link{printCrudeAndAdjustedModel}} function they
+#' for the \code{\link{printCrudeAndAdjustedModel}()} function they
 #' have been gathered into a list. This function is simply a 
 #' helper in order to generate a valid list.
 #' 
 #' @param show_tot_perc Show percentages for the total column
 #' @param numb_first Whether to show the number before the percentages
 #' @param continuous_fn Stat function used for the descriptive statistics, 
-#'  defaults to \code{\link{describeMean}}
+#'  defaults to \code{\link{describeMean}()}
 #' @param prop_fn Stat function used for the descriptive statistics, 
-#'  defaults to \code{\link{describeFactors}} since there has to be a reference
+#'  defaults to \code{\link{describeFactors}()} since there has to be a reference
 #'  in the current setup.
 #' @param factor_fn Stat function used for the descriptive statistics, 
-#'  defaults to \code{\link{describeFactors}}
+#'  defaults to \code{\link{describeFactors}()}
 #' @param digits Number of digits to use in the descriptive columns. 
 #'  Defaults to the general digits if not specified.
 #' @param colnames The names of the two descriptive columns. By default
